<?xml version='1.0' encoding='UTF-8'?>
<!-- eZois                                                          -->
<!-- Digital text-critical editions of Slovene literature           -->
<!-- ZRC SAZU, IJS                                                  -->
<!--                                                                -->
<!-- Stylesheet for conversion of TEI eZois to HTML                 -->
<!-- Parallel output only                                           -->
<!--                                                                -->
<!-- Toma&zcaron; Erjavec,                                          -->
<!-- 2007-02-04                                                    -->

<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
  xmlns:exsl="http://exslt.org/common" exclude-result-prefixes="exsl"
  extension-element-prefixes="exsl" version="1.1">

  <xsl:import href="hdr2html.xsl"/>

  <xsl:param name="outName">zois</xsl:param>
  <xsl:param name="outDir"></xsl:param>
  <xsl:param name="split"/>
  <xsl:param name="debug"/>
  <xsl:param name="verbose">yes</xsl:param>

  <xsl:param name="outFile" select="concat($outName,'.html')"/>

  <xsl:param name="homeURL" select="$outFile"/>
  <xsl:param name="teiHeader-en" select="concat($outName,'.teiHeader','-en','.html')"/>
  <xsl:param name="teiHeader-sl" select="concat($outName,'.teiHeader','-sl','.html')"/>
  <xsl:param name="teiHeader-desc-en">ENGLISH TEI HEADER</xsl:param>
  <xsl:param name="teiHeader-desc-sl">Kolofon TEI</xsl:param>
  
  <xsl:variable name="css_style">
    BODY      { 
    color: #000000;
    background-color: #FFFFCC;
    font-family: "Times New Roman", "Times";
    }
    A:visited { color: #000077;}
    .normal   { font-family: Times; }
    .break    { margin-top: 3px; margin-bottom: 3px}
    .center   { text-align: center; }
    .right    { text-align: right; }
    .justify  { text-align: justify; }
    .suphead  { font-weight: normal; }
    .subhead  { font-weight: normal; font-size: small}
  </xsl:variable>
  
  <xsl:param name="def-title">
    <xsl:text>e-Zois</xsl:text>
  </xsl:param>
  
  <xsl:variable name="html-footer1">
    <hr/>
    <SMALL>
      Avtorske pravice za to izdajo ureja licenca <!-- Uredni bljah: To delo je licencirano <sic>z</sic> --> 
      <a rel="license" href="http://creativecommons.org/licenses/by-sa/2.5/si/">Creative Commons Priznanje avtorstva-Deljenje pod enakimi pogoji 2.5 Slovenija</a>
      <br/>Projekt 
      <A HREF="http://nl.ijs.si/e-zrc/">Elektronske 
        znanstvenokriti&#x10D;ne izdaje slovenskega slovstva</A> 
      <BR/>
      Datoteka HTML narejena s pretvorbo XSLT baze 
      XML/<A HREF="http://www.tei-c.org/P4X/">TEI P4</A>.
    </SMALL>
  </xsl:variable>
  <xsl:variable name="html-footer2">
    <SMALL>
      <BR/>
      <A HREF="http://validator.w3.org/check?uri=referer"><IMG border="0"
        src="http://www.w3.org/Icons/valid-html401"
        alt="Valid HTML 4.01!" height="31" width="88"/></A>
      <A HREF="http://jigsaw.w3.org/css-validator/"><IMG border="0"
        src="http://www.w3.org/Icons/valid-css" 
        alt="Valid CSS!" height="31" width="88" /></A> 
      <xsl:comment>Creative Commons License</xsl:comment>
      <a rel="license" href="http://creativecommons.org/licenses/by-sa/2.5/si/"><img alt="Creative Commons License" style="border-width: 0" src="http://i.creativecommons.org/l/by-sa/2.5/si/88x31.png"/></a>
      <xsl:comment>/Creative Commons License</xsl:comment>
      <xsl:comment>
        <rdf:RDF xmlns="http://web.resource.org/cc/" xmlns:dc="http://purl.org/dc/elements/1.1/" xmlns:rdf="http://www.w3.org/1999/02/22-rdf-syntax-ns#" xmlns:rdfs="http://www.w3.org/2000/01/rdf-schema#">
          <Work rdf:about="">
            <license rdf:resource="http://creativecommons.org/licenses/by-sa/2.5/si/" />
          </Work>
          <License rdf:about="http://creativecommons.org/licenses/by-sa/2.5/si/"><permits rdf:resource="http://web.resource.org/cc/Reproduction"/><permits rdf:resource="http://web.resource.org/cc/Distribution"/><requires rdf:resource="http://web.resource.org/cc/Notice"/><requires rdf:resource="http://web.resource.org/cc/Attribution"/><permits rdf:resource="http://web.resource.org/cc/DerivativeWorks"/><requires rdf:resource="http://web.resource.org/cc/ShareAlike"/></License></rdf:RDF> 
      </xsl:comment>
    </SMALL>
  </xsl:variable>
  
  <xsl:output
    method="html"
    encoding="utf-8"
    indent = "yes"/> 
  
  <xsl:strip-space elements="div"/>
  <xsl:preserve-space elements="p note"/>

  <xsl:template match="/">
    <xsl:call-template name="outputChunk">
      <xsl:with-param name="outFile" select="$teiHeader-sl"/>
      <xsl:with-param name="title" 
        select="concat($teiHeader-desc-sl,': ',
        //teiHeader/fileDesc/titleStmt/title[not(@lang) or @lang='sl'])"/>
      <xsl:with-param name="content">
        <xsl:apply-templates select="TEI.2/teiHeader"/>
      </xsl:with-param>
    </xsl:call-template>
    <xsl:apply-templates select="TEI.2/text"/>
  </xsl:template>
  
  <xsl:template match="text">
    <xsl:variable name="title">
      <xsl:choose>
        <xsl:when test="//teiHeader">
          <xsl:value-of select="//fileDesc/titleStmt/title"/>
          <xsl:text> (</xsl:text>
          <xsl:value-of select="//teiHeader/@date.updated"/>
          <xsl:text>)</xsl:text>
        </xsl:when>
        <xsl:otherwise>
          <xsl:copy-of select="$def-title"/>
          <xsl:text></xsl:text>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:variable name="head">
      <xsl:choose>
        <xsl:when test="//teiHeader">
          <H1 align="center">
            <xsl:value-of select="$title"/>
          </H1>
          <xsl:for-each select="//fileDesc/titleStmt/author">
            <H2><xsl:value-of select="."/></H2>
          </xsl:for-each>
          <H2>Izdaja <xsl:value-of select="//editionStmt/edition"/></H2>
          <xsl:for-each select="//fileDesc/titleStmt/respStmt">
            <H3>
              <xsl:value-of select="resp"/>
              <xsl:text> </xsl:text>        
              <xsl:value-of select="name"/>
            </H3>
          </xsl:for-each>
        </xsl:when>
        <xsl:otherwise>
          <H1 align="center">
            <xsl:copy-of select="$def-title"/>
          </H1>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <xsl:call-template name="outputChunk">
      <xsl:with-param name="outFile" select="$outFile"/>
      <xsl:with-param name="title" select="$def-title"/>
      <xsl:with-param name="content">
        <xsl:apply-templates select="front/titlePage"/>
        <xsl:call-template name="toc"/>
        <xsl:apply-templates select="front/div"/>
        <xsl:apply-templates select="body"/>
        <xsl:apply-templates select="back"/>
      </xsl:with-param>
    </xsl:call-template>
  </xsl:template>
  
  <xsl:template name="toc">
    <A name="TOC"/>
    <H2>Kazalo</H2>
    <xsl:if test="//teiHeader">
      <A HREF="{$teiHeader-sl}">
        <xsl:value-of select="$teiHeader-desc-sl"/>
      </A>
      <P/>
    </xsl:if>
    <xsl:if test="//front">
      <B>UVOD</B>
      <UL>
        <xsl:apply-templates mode="toc" select="//front/div"/>
      </UL>
    </xsl:if>
    <B>PISMA</B>
    <UL>
      <xsl:apply-templates mode="toc" select="//div[@type='pismo']"/>
    </UL>
    <B>DODATKI</B>
    <xsl:if test="//back">
      <UL>
        <xsl:apply-templates mode="toc" select="//back"/>
      </UL>
    </xsl:if>
  </xsl:template>

  <xsl:template name="outputChunk">
    <xsl:param name="outFile" select="concat(@id,'.html')"/>
    <xsl:param name="absFile" select="concat($outDir,$outFile)"/>
    <xsl:param name="title">
      <xsl:value-of select="$id"/>
    </xsl:param>
    <xsl:param name="content"/>
    <xsl:choose>
      <xsl:when test="element-available('exsl:document')">
        <xsl:if test="$verbose='yes'">
          <xsl:message>Opening <xsl:value-of select="$absFile"/></xsl:message>
        </xsl:if>
        <exsl:document         
          encoding="utf-8" 
          method="html" 
          doctype-public="-//W3C//DTD HTML 4.01 Transitional//EN" 
          href="{$absFile}">
          <HTML>
            <xsl:comment>THIS FILE IS GENERATED FROM AN XML MASTER. DO NOT EDIT!</xsl:comment>
            <xsl:text>&#10;</xsl:text>
            <HEAD>
              <TITLE>
                <xsl:value-of select="normalize-space($title)"/>
              </TITLE>
              <META http-equiv="Content-Type" content="text/html; charset=utf-8"/>
              <STYLE TYPE="text/css">
                <xsl:value-of select="$css_style"/>
              </STYLE>
            </HEAD>
            <BODY>
              <xsl:copy-of select="$content"/>
              <xsl:copy-of select="$html-footer1"/>
              <xsl:if test="not(ancestor-or-self::teiHeader or descendant::teiHeader)">
                <xsl:copy-of select="$html-footer2"/>
              </xsl:if>
            </BODY>
          </HTML>
        </exsl:document> 
        <xsl:if test="$verbose='yes'">
          <xsl:message>Closing <xsl:value-of select="$absFile"/></xsl:message>
        </xsl:if>
      </xsl:when>
      <xsl:otherwise>
        <xsl:if test="$verbose='yes'">
          <xsl:message>Creation of 
            <xsl:value-of select="$absFile"/> not possible</xsl:message>
        </xsl:if>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>
  
  <xsl:template match="body">
    <xsl:if test="$split">
      <H2 align="center">PISMA</H2>
      <UL>
        <xsl:apply-templates mode="toc" select="//div[@type='pismo']"/>
      </UL>
    </xsl:if>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="front">
    <xsl:apply-templates/>
    <HR/>
    <HR/>
  </xsl:template>

  <xsl:template match="docImprint">
    <H4 align="center">
      <xsl:apply-templates/>
    </H4>
  </xsl:template>
  
  <xsl:template match="docAuthor">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  
  <xsl:template match="byline/docAuthor">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="byline">
    <H3 align="center">
      <xsl:apply-templates/>
    </H3>
  </xsl:template>
  
  <xsl:template match="back">
    <HR/>
    <HR/>
    <xsl:apply-templates/>
  </xsl:template>

  <xsl:template match="div[@type='facs']" mode="toc"/>

  <xsl:template match="div | divGen" mode="toc">
    <xsl:variable name="id">
      <xsl:if test="$split and (ancestor::body)">
        <xsl:value-of select="ancestor-or-self::div[@type='pismo']/@id"/>
        <xsl:text>.html</xsl:text>
      </xsl:if>
      <xsl:text>#</xsl:text>
      <xsl:choose>
        <xsl:when test="@id">
          <xsl:value-of select="@id"/>
        </xsl:when>
        <xsl:otherwise>
          <xsl:value-of select="generate-id(.)"/>
        </xsl:otherwise>
      </xsl:choose>
    </xsl:variable>
    <LI>
      <A href="{$id}">
        <xsl:choose>
          <xsl:when test="@type = 'pismo'">
            <xsl:apply-templates select="head" mode="toc"/>
          </xsl:when>
          <xsl:when test="name() = 'divGen'">
            <xsl:value-of select="../head[1]"/>
            <xsl:text> (vzporedni prikaz)</xsl:text>
          </xsl:when>
          <xsl:otherwise>
            <xsl:apply-templates select="head" mode="toc"/>
          </xsl:otherwise>
        </xsl:choose>
      </A>
    </LI>
  </xsl:template>

  <xsl:template match="div[@type='pismo']">
    <xsl:if test="$verbose='yes'">
      <xsl:message>Processing div <xsl:value-of select="@id"/></xsl:message>
    </xsl:if>
    <xsl:choose>
      <xsl:when test="$split">
        <xsl:call-template name="outputChunk">
          <xsl:with-param name="outFile" select="concat(@id,'.html')"/>
          <xsl:with-param name="title">
            <xsl:value-of select="$def-title"/>
            <xsl:text>: </xsl:text>
            <xsl:apply-templates mode="toc" select="head"/>
          </xsl:with-param>
          <xsl:with-param name="content">
            <xsl:apply-templates select="head"/>
            <xsl:call-template name="pismo"/>
          </xsl:with-param>
        </xsl:call-template>
      </xsl:when>
      <xsl:otherwise>
        <HR/>
        <xsl:apply-templates select="head"/>
        <xsl:call-template name="pismo"/>
        <HR/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template name="pismo">
    <xsl:call-template name="anchor"/>
    <H3>Kazalo</H3>
    <UL>
      <xsl:if test="not($debug)">
        <xsl:apply-templates select="div" mode="toc"/>
      </xsl:if>
      <xsl:apply-templates select="divGen" mode="toc"/>
      <LI>
        <A href="#{@id}.notes">
          <xsl:value-of select="head[1]"/>
          <xsl:text> (opombe)</xsl:text>
        </A>
      </LI>
      <LI>
        <A href="{$outName}.html#TOC">
          <xsl:text>na glavno kazalo</xsl:text>
        </A>
      </LI>
    </UL>
    <xsl:if test="not($debug)">
      <xsl:apply-templates select="div"/>
    </xsl:if>
    <xsl:apply-templates select="divGen"/>
    <HR/>
    <A name="{@id}.notes"/>
    <H3>Opombe</H3>
    <OL>
      <xsl:apply-templates select=".//note[@place='inline']" mode="show"/>
    </OL>
    <xsl:if test="$split">
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
    </xsl:if>
  </xsl:template>

  <xsl:template match="div[@type='facs']"/>

  <xsl:template match="div[@type='dipl' or @type='crit']">
    <HR/>
    <xsl:call-template name="anchor"/>
    <H3 align="center">
      <xsl:apply-templates select="../head" mode="toc"/>
    </H3>
    <TABLE>
      <TR>
        <xsl:apply-templates mode="para" select="../div[@type='facs']/head"/>
        <xsl:apply-templates mode="para" select="head"/>
      </TR>
      <xsl:for-each select="page">
        <TR>
          <TD valign="top">
            <A href="{id(@corresp)/figure[@type='jpeg']/@url}">
              <IMG src="{id(@corresp)/figure[@type='thmb']/@url}"
                alt="{id(@corresp)/figure[@type='jpeg']/figDesc}"/>
            </A>
          </TD>
          <TD valign="top">
            <HR/>
            <xsl:apply-templates/>
          </TD>
        </TR>
      </xsl:for-each>
    </TABLE>
  </xsl:template>

  <xsl:template match="divGen">
    <HR/>
    <xsl:call-template name="anchor"/>
    <H3 align="center">
      <xsl:apply-templates select="../head" mode="toc"/>
    </H3>
    <TABLE>
      <TR>
        <xsl:apply-templates mode="para" select="../div[@type='facs']/head"/>
        <TD>
          <TABLE width="100%">
            <TR>
              <xsl:apply-templates mode="para" select="../div[@type='dipl']/head"/>
              <xsl:apply-templates mode="para" select="../div[@type='crit']/head"/>
            </TR>
          </TABLE>
        </TD>
      </TR>
      <xsl:apply-templates mode="para2" select="../div[@type='facs']/page"/>
    </TABLE>
  </xsl:template>

  <xsl:template match="div">
    <xsl:if test="not(@type='subs')">
      <HR/>
    </xsl:if>
    <xsl:call-template name="anchor"/>
    <xsl:apply-templates/>
    <xsl:if test="@type='bibl'">
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
      <BR/>
    </xsl:if>
  </xsl:template>

  <xsl:template mode="para2" match="div[@type='facs']/page">
    <TR>
      <TD valign="top">
        <A href="{figure[@type='jpeg']/@url}">
          <IMG src="{figure[@type='thmb']/@url}" alt="{figure[@type='jpeg']/figDesc}"/>
        </A>
      </TD>
      <TD valign="top">
        <xsl:variable name="corresp" select="@corresp"/>
        <xsl:apply-templates mode="para2" select="id($corresp)[../@type='dipl']"/>
      </TD>
    </TR>
  </xsl:template>

  <xsl:template match="head" mode="para">
    <TH>
      <xsl:apply-templates/>
    </TH>
  </xsl:template>

  <xsl:template match="head" mode="toc">
    <xsl:choose>
      <xsl:when test="position() = 2">
        <xsl:text>: </xsl:text>
      </xsl:when>
      <xsl:when test="position() = 3">
        <xsl:text>; </xsl:text>
      </xsl:when>
    </xsl:choose>
    <xsl:apply-templates select="text()"/>
  </xsl:template>

  <xsl:template match="div/div/head" priority="2">
    <H3>
      <xsl:apply-templates/>
    </H3>
  </xsl:template>

  <xsl:template match="div/head" priority="1">
    <H2 align="center">
      <xsl:apply-templates/>
    </H2>
  </xsl:template>

  <xsl:template mode="para2" match="div[@type='dipl']/page">
    <TABLE border="border">
      <xsl:apply-templates mode="para2" select="p"/>
    </TABLE>
  </xsl:template>

  <xsl:template mode="para2" match="p">
    <TR>
      <TD>
        <xsl:apply-templates/>
      </TD>
      <TD>
        <xsl:apply-templates select="id(@corresp)"/>
      </TD>
    </TR>
  </xsl:template>

  <xsl:template match="p">
    <p>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </p>
  </xsl:template>

  <xsl:template match="note[@place='inline']">
    <A name="{@id}.{@place}"/>
    <SUP>
      <A href="#{@id}">
        <xsl:number level="any" count="note" from="div[@type='pismo']"/>
      </A>
    </SUP>
  </xsl:template>

  <xsl:template match="note" mode="show">
    <LI>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
      <xsl:if test="$debug">
        <xsl:text> [</xsl:text>
        <A href="#{@id}.{@place}">nazaj</A>
        <xsl:text>]</xsl:text>
      </xsl:if>
    </LI>
  </xsl:template>

  <xsl:template match="titlePage">
    <xsl:apply-templates/>
    <HR/>
  </xsl:template>
  
  <xsl:template match="docTitle">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  
  <xsl:template match="docTitle[titlePart]">
    <xsl:apply-templates/>
  </xsl:template>
  
  <xsl:template match="titlePart">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  
  <xsl:template match="titlePart[@type='subtitle']">
    <H2 align="center">
      <xsl:apply-templates/>
    </H2>
  </xsl:template>
  
  <xsl:template match="docImprint">
    <H4 align="center">
      <xsl:apply-templates/>
    </H4>
  </xsl:template>
  
  <xsl:template match="docAuthor">
    <H1 align="center">
      <xsl:apply-templates/>
    </H1>
  </xsl:template>
  
  <xsl:template match="byline/docAuthor">
    <xsl:apply-templates/>
  </xsl:template>
  <xsl:template match="byline">
    <H3 align="center">
      <xsl:apply-templates/>
    </H3>
  </xsl:template>
  
  <xsl:template match="lb">
    <BR/>
  </xsl:template>
  
  <xsl:template match="text//name">
    <xsl:choose>
      <xsl:when test="$debug">
        <font color="purple">
          <xsl:apply-templates/>
        </font>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//date">
    <xsl:choose>
      <xsl:when test="$debug">
        <font color="violet">
          <xsl:apply-templates/>
        </font>
      </xsl:when>
      <xsl:otherwise>
        <xsl:apply-templates/>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="foreign">
    <xsl:choose>
      <xsl:when test="$debug">
        <font color="fuchsia">
          <xsl:apply-templates/>
        </font>
      </xsl:when>
      <xsl:otherwise>
        <i>
          <xsl:apply-templates/>
        </i>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="text//bibl">
    <xsl:choose>
      <xsl:when test="$debug">
        <font color="green">
          <xsl:apply-templates/>
        </font>
      </xsl:when>
      <xsl:otherwise>
        <i>
          <xsl:apply-templates/>
        </i>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="sic">
    <font color="red">
      <xsl:apply-templates/>
    </font>
  </xsl:template>

  <xsl:template match="hi[@rend='sup']">
    <sup>
      <xsl:apply-templates/>
    </sup>
  </xsl:template>
  <xsl:template match="hi[@rend='it']">
    <i>
      <xsl:apply-templates/>
    </i>
  </xsl:template>
  <xsl:template match="hi">
    <i>
      <xsl:apply-templates/>
    </i>
  </xsl:template>

  <xsl:template match="emph">
    <xsl:choose>
      <xsl:when test="contains(@rend,'dblu')">
        <u>
          <xsl:apply-templates/>
        </u>
      </xsl:when>
      <xsl:when test="@rend = 'u'">
        <u>
          <xsl:apply-templates/>
        </u>
      </xsl:when>
      <xsl:otherwise>
        <em>
          <xsl:apply-templates/>
        </em>
      </xsl:otherwise>
    </xsl:choose>
  </xsl:template>

  <xsl:template match="add">
    <sup>
      <xsl:apply-templates/>
    </sup>
  </xsl:template>
  <xsl:template match="add[@hand='JFA' or @hand='MOG']">
    <xsl:text>[</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>]</xsl:text>
  </xsl:template>
  <xsl:template match="del">
    <s>
      <xsl:apply-templates/>
    </s>
  </xsl:template>
  <xsl:template match="del[@hand='JFA']">
    <xsl:text>&#x2026;</xsl:text>
  </xsl:template>

  <xsl:template match="gap">
    <xsl:text>[&#x2026;]</xsl:text>
  </xsl:template>

  <xsl:template match="gap[ancestor::div[@type='crit']]">
    <i>
      <xsl:text>(besedilo uni&#x10D;eno)</xsl:text>
    </i>
  </xsl:template>

  <xsl:template match="supplied">
    <xsl:text> !!!</xsl:text>
    <xsl:apply-templates/>
    <xsl:text>!!! </xsl:text>
  </xsl:template>

  <xsl:template match="list">
    <UL>
      <xsl:apply-templates/>
    </UL>
  </xsl:template>

  <xsl:template match="item">
    <LI>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="listBibl">
    <OL>
      <xsl:apply-templates/>
    </OL>
  </xsl:template>

  <xsl:template match="listBibl/bibl">
    <LI>
      <xsl:call-template name="anchor"/>
      <xsl:apply-templates/>
    </LI>
  </xsl:template>

  <xsl:template match="ref">
    <xsl:variable name="base">
      <xsl:if test="$split">
        <xsl:choose>
          <xsl:when test="id(@target)/ancestor-or-self::div[@type='pismo']">
            <xsl:value-of select="id(@target)/ancestor-or-self::div[@type='pismo']/@id"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="$outName"/>
          </xsl:otherwise>
        </xsl:choose>
        <xsl:text>.html</xsl:text>
      </xsl:if>
    </xsl:variable>
    <A href="{$base}#{@target}">
      <xsl:apply-templates/>
    </A>
  </xsl:template>

  <xsl:template match="xref">
    <A href="{@url}">
      <xsl:apply-templates/>
    </A>
  </xsl:template>

  <xsl:template name="anchor">
    <A>
      <xsl:attribute name="name">
        <xsl:choose>
          <xsl:when test="@id">
            <xsl:value-of select="@id"/>
          </xsl:when>
          <xsl:otherwise>
            <xsl:value-of select="generate-id(.)"/>
          </xsl:otherwise>
        </xsl:choose>
      </xsl:attribute>
    </A>
  </xsl:template>

</xsl:stylesheet>
